@@ -133,7 +133,7 @@
 //! 
 //! ```rust
 //! use serde_json::Value;
-//! use yedb::YedbClientAsync;
+//! use yedb::{YedbClientAsync, YedbClientAsyncExt};
 //! 
 //! async fn test() {
 //!     let mut client = YedbClientAsync::new("tcp://127.0.0.1:8870");
@@ -150,7 +150,7 @@
 //! use serde_json::Value;
 //! use std::sync::Arc;
 //! use std::time::Duration;
-//! use yedb::YedbClientPoolAsync;
+//! use yedb::{YedbClientPoolAsync, YedbClientAsyncExt};
 //! 
 //! async fn test() {
 //!     let pool = Arc::new(
@@ -233,7 +233,7 @@ use log::{debug, error, warn};
 extern crate lazy_static;
 
 pub const SERVER_ID: &str = "yedb-altt-rs";
-pub const VERSION: &str = "0.2.1";
+pub const VERSION: &str = "0.3.0";
 pub const ENGINE_VERSION: u8 = 1;
 
 pub const DEFAULT_CACHE_SIZE: usize = 1000;
@@ -274,19 +274,27 @@ impl ExplainValue for Value {
 pub mod common;
 pub use common::{DBInfo, Error, ErrorKind, KeyExplained};
 
-#[cfg(any(feature = "client-sync", feature = "cli"))]
+#[cfg(feature = "client-sync")]
 #[path = "client.rs"]
 pub mod client;
-#[cfg(any(feature = "client-sync", feature = "cli"))]
+#[cfg(feature = "client-sync")]
 pub use client::YedbClient;
 
 #[cfg(feature = "client-async")]
 #[path = "client_async.rs"]
 pub mod client_async;
 #[cfg(feature = "client-async")]
-pub use client_async::YedbClientAsync;
-#[cfg(feature = "client-async")]
-pub use client_async::YedbClientPoolAsync;
+pub use client_async::{YedbClientAsync, YedbClientAsyncExt, YedbClientPoolAsync};
+
+#[cfg(feature = "client-elbus-async")]
+#[path = "client_elbus_async.rs"]
+pub mod client_elbus_async;
+#[cfg(feature = "client-elbus-async")]
+pub use client_elbus_async::YedbClientElbusAsync;
+
+#[cfg(any(feature = "server", feature = "server-embed"))]
+#[path = "server.rs"]
+pub mod server;
 
 #[derive(Debug)]
 enum DataKey<'a> {
@@ -538,7 +546,7 @@ impl Engine {
     }
 }
 
-#[derive(Serialize)]
+#[derive(Serialize, Debug)]
 pub struct ServerInfo {
     pub name: String,
     pub version: u8,
@@ -709,7 +717,7 @@ impl Database {
     fn need_skip_bak(&self, key: &str) -> bool {
         for k in &self.skip_bak {
             let l = k.len();
-            if k == key || (key.starts_with(k) && key.get(l..l + 1).map_or(false, |s| s == "/")) {
+            if k == key || (key.starts_with(k) && key.get(l..=l).map_or(false, |s| s == "/")) {
                 return true;
             }
         }
@@ -1068,7 +1076,7 @@ impl Database {
         debug!("Purging cache for {}*", key);
         let to_remove: Vec<_> = self
             .cache
-            .iter_mut()
+            .iter()
             .filter(|&(k, _)| k.starts_with(&key))
             .map(|(k, _)| k.clone())
             .collect();
@@ -1462,7 +1470,7 @@ impl Database {
                 return Err(Error::new(
                     ErrorKind::DataError,
                     format!("Invalid server option value {}={}", $n, $value),
-                ));
+                ))
             };
         }
         match name {
